Class: Module

Inherits:
Object
  • Object
show all
Defined in:
lib/paramix.rb

Direct Known Subclasses

Paramix::Delegator

Instance Method Summary collapse

Instance Method Details

#mixin_parametersObject Also known as: mixin_params

Store for parametric mixin parameters.

Returns a hash, the keys of which are the parametric mixin module and the values are the parameters associacted with this module/class.

class C
  include P(:x=>1)
end

C.mixin_parameters[P]   #=> {:x=>1}


194
195
196
# File 'lib/paramix.rb', line 194

def mixin_parameters
  @mixin_parameters ||= {}
end